window.Gleam.initSearch([{"doc":"lustre_transition","title":"lustre_transition","content":"# lustre_transition\n\n[![Package Version](https://img.shields.io/hexpm/v/lustre_transition)](https://hex.pm/packages/lustre_transition)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/lustre_transition/)\n\n## Installation\n\n1. Add lustre to your project\n\nLustre is published on [Hex](https://hex.pm/packages/lustre)! You can add it to\nyour Gleam projects from the command line:\n\n```sh\ngleam add lustre\n```\n\n2. Add lustre_transitions to your project\n\n```sh\ngleam add lustre_transitions\n```\n\n2. Add lustre_dev_tools to your project\n\nLustre&#39;s dev tools are published on [Hex](https://hex.pm/packages/lustre_dev_tools)!\nYou can add them as a dev dependency to your Gleam projects from the command line:\n\n&gt; **Note**: currently one of lustre_dev_tools&#39; dependencies is not compatible with\n&gt; the most recent version of `gleam_json`, making it impossible to install. To fix\n&gt; this, add `gleam_json = &quot;1.0.1&quot;` as a dependency in your `gleam.toml` file.\n\n```sh\ngleam add lustre_dev_tools --dev\n```\n\n3. Add tailwind support\n\nDownload a platform-appropriate version of the Tailwind binary.\n\n```sh\ngleam run -m lustre/dev add tailwind\n```\n\n4. Serve your project\n\nStart a development server for your Lustre project. This\ncommand will compile your application and serve it on a local server.\n\n```sh \ngleam run -m lustre/dev start\n```\n\n## Example \n\n\n```gleam\nimport gleam/dynamic\nimport gleam/option.{Some}\nimport gleam/result\nimport lustre\nimport lustre/attribute\nimport lustre/effect.{type Effect}\nimport lustre/element.{type Element}\nimport lustre/element/html\nimport lustre/event\nimport transition.{type State}\n\npub fn main() {\n  let app = lustre.application(init, update, view)\n  let assert Ok(_) = lustre.start(app, &quot;#app&quot;, Nil)\n}\n\ntype Model {\n  Model(panel_state: transition.State)\n}\n\npub opaque type Msg {\n  UserClickedButton\n  TransitionStarted\n  TransitionEnded(String)\n}\n\nfn init(_flags) -&gt; #(Model, Effect(Msg)) {\n  #(Model(transition.Init), effect.none())\n}\n\nfn update(model: Model, msg: Msg) -&gt; #(Model, Effect(Msg)) {\n  case msg {\n    UserClickedButton -&gt; #(\n      Model(panel_state: transition.toggle(Some(model.panel_state))),\n      transition.start(TransitionStarted),\n    )\n    TransitionStarted -&gt; #(\n      Model(panel_state: transition.next(Some(model.panel_state))),\n      effect.none(),\n    )\n    TransitionEnded(_) -&gt; #(\n      Model(panel_state: transition.end(Some(model.panel_state))),\n      effect.none(),\n    )\n  }\n}\n\nfn view(model: Model) -&gt; Element(Msg) {\n  html.div([attribute.class(&quot;p-4&quot;)], [\n    html.button(\n      [\n        event.on_click(UserClickedButton),\n        attribute.class(\n          &quot;rounded-md bg-indigo-600 px-3 py-2 text-sm font-semibold text-white shadow-sm hover:bg-indigo-500 focus-visible:outline focusivisible:outline-2 focus-visible:outline-indigo-600&quot;,\n        ),\n      ],\n      [element.text(&quot;Click Me!&quot;)],\n    ),\n    panel(model.panel_state),\n  ])\n}\n\nfn panel(state: State) {\n  // &quot;hidden&quot; - we need to add this here so that tailwind doesn&#39;t strip out this class\n  let classes =\n    transition.Classes(\n      enter: #(\n        &quot;transition ease-out duration-300&quot;,\n        &quot;opacity-0 scale-90&quot;,\n        &quot;opacity-100 scale-100&quot;,\n      ),\n      leave: #(\n        &quot;transition ease-in duration-300&quot;,\n        &quot;opacity-100 scale-100&quot;,\n        &quot;opacity-0 scale-90&quot;,\n      ),\n    )\n    |&gt; transition.apply(state)\n  html.div(\n    [\n      attribute.class(classes),\n      attribute.id(&quot;hello&quot;),\n      event.on(&quot;transitionend&quot;, handle_transition_end),\n    ],\n    [element.text(&quot;Hello World!&quot;)],\n  )\n}\n\nfn handle_transition_end(event) -&gt; Result(Msg, List(dynamic.DecodeError)) {\n  use target &lt;- result.try(dynamic.field(&quot;target&quot;, dynamic.dynamic)(event))\n  use id &lt;- result.try(dynamic.field(&quot;id&quot;, dynamic.string)(target))\n  Ok(TransitionEnded(id))\n}\n```\n\n\nFurther documentation can be found at &lt;https://hexdocs.pm/lustre_transition&gt;.\n\n","url":"index.html"},{"doc":"transition","title":"Classes","content":"pub type Classes {\n  Classes(\n    enter: #(String, String, String),\n    leave: #(String, String, String),\n  )\n}\n Used to define what classes will be applied to your element through each stage of a transition.\nClasses(\n  enter: #(String, String, String),\n  leave: #(String, String, String),\n)\n\n\nSynonyms:\ntransition.Classes\ntransition Classes","url":"transition.html#Classes"},{"doc":"transition","title":"State","content":"pub type State {\n  Init\n  EnterInit\n  Enter\n  LeaveInit\n  Leave\n}\n\nInit\n Starting state.\n\nEnterInit\n First frame of `Enter` transition.\n\nEnter\n `Enter` transition from after second frame until the end of transition.\n\nLeaveInit\n First frame of `Leave` transition.\n\nLeave\n `Leave` transition from after second frame until the end of transition.\n\nSynonyms:\ntransition.State\ntransition State","url":"transition.html#State"},{"doc":"transition","title":"Transition","content":"pub type Transition {\n  Transition(state: State, classes: Classes)\n}\n Stores the complete information about a transition, it&#39;s state and all the classes that will be applied.\nTransition(state: State, classes: Classes)\n\n\nSynonyms:\ntransition.Transition\ntransition Transition","url":"transition.html#Transition"},{"doc":"transition","title":"apply","content":"pub fn apply(classes: Classes, state: State) -&gt; String\n Use the supplied state to select the correct classes to display on the element.\nSynonyms:\ntransition.apply\ntransition apply","url":"transition.html#apply"},{"doc":"transition","title":"end","content":"pub fn end(state: Option(State)) -&gt; State\n Use the `transitionend` event to call this, it will update the state back to `Init`.\nSynonyms:\ntransition.end\ntransition end","url":"transition.html#end"},{"doc":"transition","title":"next","content":"pub fn next(state: Option(State)) -&gt; State\n Move the state on from `Init`, e.g. `EnterInit` -&gt; `Enter`, `LeaveInit` -&gt; `Leave`.\nSynonyms:\ntransition.next\ntransition next","url":"transition.html#next"},{"doc":"transition","title":"start","content":"pub fn start(msg: a) -&gt; Effect(a)\n Used to trigger the start of an animation. `Msg` will be dispatched on the next frame. \nSynonyms:\ntransition.start\ntransition start","url":"transition.html#start"},{"doc":"transition","title":"state_to_string","content":"pub fn state_to_string(state: State) -&gt; String\n Convert the state to a string for debugging purposes.\nSynonyms:\ntransition.state_to_string\ntransition state_to_string","url":"transition.html#state_to_string"},{"doc":"transition","title":"toggle","content":"pub fn toggle(state: Option(State)) -&gt; State\n Toggle the state from any `Leave` state to `EnterInit`, or any `Enter` state to `LeaveInit`.\nSynonyms:\ntransition.toggle\ntransition toggle","url":"transition.html#toggle"},{"doc":"transition","title":"transition","content":"","url":"transition.html"}]);